<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>AddImage</name>
    <message>
        <location filename="../src/add_image.cpp" line="87"/>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="59"/>
        <source>Appearance</source>
        <translation>Вигляд</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="68"/>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="70"/>
        <source>Beveled borders</source>
        <translation>Скісні краї</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="73"/>
        <source>Drop shadows</source>
        <translation>Різкі тіні</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="77"/>
        <source>Colors</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="96"/>
        <source>Background:</source>
        <translation>Фон:</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="97"/>
        <source>Shadow:</source>
        <translation>Тінь:</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="98"/>
        <source>Highlight:</source>
        <translation>Підсвічування:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="187"/>
        <location filename="../src/board.cpp" line="293"/>
        <location filename="../src/board.cpp" line="361"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="187"/>
        <location filename="../src/board.cpp" line="293"/>
        <source>Missing image.</source>
        <translation>Зображення немає.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="194"/>
        <location filename="../src/board.cpp" line="269"/>
        <location filename="../src/main.cpp" line="146"/>
        <source>Please Wait</source>
        <translation>Будь ласка, зачекайте</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="216"/>
        <location filename="../src/board.cpp" line="368"/>
        <source>Loading image...</source>
        <translation>Завантаження зображення...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="222"/>
        <source>Generating puzzle...</source>
        <translation>Генерування пазла...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="228"/>
        <location filename="../src/board.cpp" line="242"/>
        <source>Creating pieces...</source>
        <translation>Створення елементів...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="281"/>
        <source>Loading puzzle...</source>
        <translation>Завантаження пазла...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="306"/>
        <source>Unknown data format</source>
        <translation>Невідомий формат даних</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="356"/>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Невідомий елемент «%1»</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="361"/>
        <source>Error parsing XML file.

%1</source>
        <translation>Error parsing XML file.

%1</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="372"/>
        <source>Loading pieces...</source>
        <translation>Завантаження елементів...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="454"/>
        <source>Retrieving pieces...</source>
        <translation>Отримання елементів...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="994"/>
        <source>Placing pieces...</source>
        <translation>Розташування елементів...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="1326"/>
        <source>Success</source>
        <translation>Успішно</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <location filename="../src/choose_game_dialog.cpp" line="38"/>
        <source>Choose Game</source>
        <translation>Вибрати гру</translation>
    </message>
    <message>
        <location filename="../src/choose_game_dialog.cpp" line="52"/>
        <source>Current Games</source>
        <translation>Поточні ігри</translation>
    </message>
    <message>
        <location filename="../src/choose_game_dialog.cpp" line="57"/>
        <source>New Game</source>
        <translation>Нова гра</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <location filename="../src/image_properties_dialog.cpp" line="39"/>
        <source>Image Properties</source>
        <translation>Властивості зображення</translation>
    </message>
    <message>
        <location filename="../src/image_properties_dialog.cpp" line="72"/>
        <source>Name:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <location filename="../src/image_properties_dialog.cpp" line="73"/>
        <source>Tags:</source>
        <translation>Мітки:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Вибрати мову програми:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системна мова&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Нотатка</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустіть програму, щоб зміна мови набула сили.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <location filename="../src/new_game_tab.cpp" line="105"/>
        <source>Add Image</source>
        <translation>Додати зображення</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="109"/>
        <location filename="../src/new_game_tab.cpp" line="290"/>
        <source>Remove Image</source>
        <translation>Вилучити зображення</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="113"/>
        <source>Image Properties</source>
        <translation>Властивості зображення</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="132"/>
        <location filename="../src/new_game_tab.cpp" line="383"/>
        <source>%L1 pieces</source>
        <translation>%L1 елементів</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="193"/>
        <source>Copying images...</source>
        <translation>Копіювання зображень...</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="286"/>
        <source>Remove selected image?</source>
        <translation>Вилучити вибране зображення?</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="288"/>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Вилучити вибране зображення?

Є збережені ігри з таким зображенням, що також будуть вилучені.</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="493"/>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <location filename="../src/open_game_tab.cpp" line="86"/>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="89"/>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 елементів %2 %3% завершено</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="105"/>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="148"/>
        <source>Delete Game</source>
        <translation>Вилучити гру</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="148"/>
        <source>Delete selected game?</source>
        <translation>Вилучити вибрану гру?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <location filename="../src/overview.cpp" line="38"/>
        <source>Overview</source>
        <translation>Огляд</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <location filename="../src/tag_manager.cpp" line="50"/>
        <source>Add Tag</source>
        <translation>Додати мітку</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="54"/>
        <source>Remove Tag</source>
        <translation>Вилучити мітку</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="59"/>
        <source>Untagged</source>
        <translation>Без мітки</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="88"/>
        <source>All Images</source>
        <translation>Всі зображення</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="208"/>
        <source>Untitled %1</source>
        <translation>Без назви %1</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="232"/>
        <source>Question</source>
        <translation>Запит</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="232"/>
        <source>Remove selected tag?</source>
        <translation>Вилучити вибрану мітку?</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="273"/>
        <source>Sorry</source>
        <translation>На жаль</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="273"/>
        <source>A tag with that name already exists.</source>
        <translation>Мітка з такою назвою вже є.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="147"/>
        <location filename="../src/window.cpp" line="50"/>
        <location filename="../src/window.cpp" line="286"/>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="84"/>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Отримати елементи</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="84"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="88"/>
        <source>&amp;Quit</source>
        <translation>&amp;Вийти</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="81"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Вибрати...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="91"/>
        <source>&amp;View</source>
        <translation>&amp;Перегляд</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="92"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Збільшити</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="92"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <source>Zoom &amp;Out</source>
        <translation>Зм&amp;еншити</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="98"/>
        <source>Best &amp;Fit</source>
        <translation>Найкращий &amp;добір</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="101"/>
        <source>Show O&amp;verview</source>
        <translation>Показати о&amp;гляд</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="101"/>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="107"/>
        <source>F&amp;ullscreen</source>
        <translation>На по&amp;вний екран</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="111"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="116"/>
        <source>&amp;Settings</source>
        <translation>&amp;Параметри</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="117"/>
        <source>&amp;Appearance...</source>
        <translation>&amp;Вигляд...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="118"/>
        <source>&amp;Language...</source>
        <translation>&amp;Мова...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>&amp;Controls</source>
        <translation>&amp;Керування</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>&amp;About</source>
        <translation>Пр&amp;о гру</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="125"/>
        <source>About &amp;Qt</source>
        <translation>Про &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="252"/>
        <source>Controls</source>
        <translation>Керування</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="259"/>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Підняти елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="260"/>
        <location filename="../src/window.cpp" line="262"/>
        <source>Left Click or Space</source>
        <translation>Ліва кнопка миші або пробіл</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="261"/>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Опустити елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="263"/>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вибрати елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>Left Drag</source>
        <translation>Перетягування лівою кнопкою</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Обернути елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Права кнопка миші, Ctrl + ліва кнопка або R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="267"/>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Перетягти пазл:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="268"/>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Середня кнопка, Shift + ліва кнопка або стрілки</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="269"/>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Масштаб пазла:&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="270"/>
        <source>Scrollwheel or +/-</source>
        <translation>Колесо миші або +/-</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="271"/>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Перемістити курсор:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="272"/>
        <source>Move mouse or W,A,D,S</source>
        <translation>Перемістити мишу або клавіші W, A, D, S</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="285"/>
        <source>About Tetzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="287"/>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="288"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="289"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <location filename="../src/zoom_slider.cpp" line="38"/>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <location filename="../src/zoom_slider.cpp" line="63"/>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
</TS>
